@@ -166,10 +166,8 @@ sub serve_error {
         $res->headers->content_type('text/html');
         $res->body(<<'EOF');
 <!doctype html><html>
-  <head><title>File Not Found</title></head>
-  <body>
-    <h2>File Not Found</h2>
-  </body>
+    <head><title>File Not Found</title></head>
+    <body><h2>File Not Found</h2></body>
 </html>
 EOF
     }
@@ -183,10 +181,8 @@ EOF
         $res->headers->content_type('text/html');
         $res->body(<<'EOF');
 <!doctype html><html>
-  <head><title>Internal Server Error</title></head>
-  <body>
-    <h2>Internal Server Error</h2>
-  </body>
+    <head><title>Internal Server Error</title></head>
+    <body><h2>Internal Server Error</h2></body>
 </html>
 EOF
     }
